<?php

namespace Mavabc\Solution\Policies;

use Litepie\User\Contracts\UserPolicy;
use Mavabc\Solution\Models\Solutions;

class SolutionsPolicy
{

    /**
     * Determine if the given user can view the solutions.
     *
     * @param UserPolicy $user
     * @param Solutions $solutions
     *
     * @return bool
     */
    public function view(UserPolicy $user, Solutions $solutions)
    {
        if ($user->canDo('solution.solutions.view') && $user->isAdmin()) {
            return true;
        }

        return $solutions->user_id == user_id() && $solutions->user_type == user_type();
    }

    /**
     * Determine if the given user can create a solutions.
     *
     * @param UserPolicy $user
     * @param Solutions $solutions
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('solution.solutions.create');
    }

    /**
     * Determine if the given user can update the given solutions.
     *
     * @param UserPolicy $user
     * @param Solutions $solutions
     *
     * @return bool
     */
    public function update(UserPolicy $user, Solutions $solutions)
    {
        if ($user->canDo('solution.solutions.edit') && $user->isAdmin()) {
            return true;
        }

        return $solutions->user_id == user_id() && $solutions->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given solutions.
     *
     * @param UserPolicy $user
     * @param Solutions $solutions
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Solutions $solutions)
    {
        return $solutions->user_id == user_id() && $solutions->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given solutions.
     *
     * @param UserPolicy $user
     * @param Solutions $solutions
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Solutions $solutions)
    {
        if ($user->canDo('solution.solutions.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given solutions.
     *
     * @param UserPolicy $user
     * @param Solutions $solutions
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Solutions $solutions)
    {
        if ($user->canDo('solution.solutions.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
