<?php

namespace Mavabc\Solution\Providers;

use Illuminate\Support\ServiceProvider;

class SolutionServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'solution');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'solution');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('mavabc.solution', function ($app) {
            return $this->app->make('Mavabc\Solution\Solution');
        });

                // Bind Solutions to repository
        $this->app->bind(
            'Mavabc\Solution\Interfaces\SolutionsRepositoryInterface',
            \Mavabc\Solution\Repositories\Eloquent\SolutionsRepository::class
        );

        $this->app->register(\Mavabc\Solution\Providers\AuthServiceProvider::class);
                $this->app->register(\Mavabc\Solution\Providers\EventServiceProvider::class);
        
        $this->app->register(\Mavabc\Solution\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['mavabc.solution'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('mavabc/solution.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/solution')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/solution')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
